@@ -1,24 +1,27 @@
 /* Declarations for insn-output.c.  These functions are defined in recog.c,
    final.c, and varasm.c.
    Copyright (C) 1987, 1991, 1994, 1997, 1998,
-   1999, 2000 Free Software Foundation, Inc.
+   1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-This file is part of GNU CC.
+This file is part of GCC.
 
-GNU CC is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+GCC is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation; either version 2, or (at your option) any later
+version.
 
-GNU CC is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+GCC is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU CC; see the file COPYING.  If not, write to
-the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+along with GCC; see the file COPYING.  If not, write to the Free
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+02111-1307, USA.  */
+
+/* Compute branch alignments based on frequency information in the CFG.  */
+extern void compute_alignments  PARAMS ((void));
 
 /* Initialize data in final at the beginning of a compilation.  */
 extern void init_final		PARAMS ((const char *));
@@ -35,7 +38,7 @@ extern void app_enable		PARAMS ((void));
    Called from varasm.c before most kinds of output.  */
 extern void app_disable		PARAMS ((void));
 
-/* Return the number of slots filled in the current 
+/* Return the number of slots filled in the current
    delayed branch sequence (we don't count the insn needing the
    delay slot).   Zero if not in a delayed branch sequence.  */
 extern int dbr_sequence_length	PARAMS ((void));
@@ -62,7 +65,7 @@ extern void final_start_function  PARAMS ((rtx, FILE *, int));
 /* Output assembler code for the end of a function.
    For clarity, args are same as those of `final_start_function'
    even though not all of them are needed.  */
-extern void final_end_function  PARAMS ((rtx, FILE *, int));
+extern void final_end_function  PARAMS ((void));
 
 /* Output assembler code for some insns: all or part of a function.  */
 extern void final		PARAMS ((rtx, FILE *, int, int));
@@ -74,11 +77,11 @@ extern rtx final_scan_insn	PARAMS ((rtx, FILE *, int, int, int));
 
 /* Replace a SUBREG with a REG or a MEM, based on the thing it is a
    subreg of.  */
-extern rtx alter_subreg PARAMS ((rtx));
+extern rtx alter_subreg PARAMS ((rtx *));
 
 /* Report inconsistency between the assembler template and the operands.
    In an `asm', it's the user's fault; otherwise, the compiler's fault.  */
-extern void output_operand_lossage  PARAMS ((const char *));
+extern void output_operand_lossage  PARAMS ((const char *, ...)) ATTRIBUTE_PRINTF_1;
 
 /* Output a string of assembler code, substituting insn operands.
    Defined in final.c.  */
@@ -116,6 +119,11 @@ extern void split_double	PARAMS ((rtx, rtx *, rtx *));
 /* Return nonzero if this function has no function calls.  */
 extern int leaf_function_p	PARAMS ((void));
 
+/* Return 1 if branch is an forward branch.
+   Uses insn_shuid array, so it works only in the final pass.  May be used by
+   output templates to add branch prediction hints, for example.  */
+extern int final_forward_branch_p PARAMS ((rtx));
+
 /* Return 1 if this function uses only the registers that can be
    safely renumbered.  */
 extern int only_leaf_regs_used	PARAMS ((void));
@@ -127,15 +135,16 @@ extern void leaf_renumber_regs_insn PARAMS ((rtx));
 /* Locate the proper template for the given insn-code.  */
 extern const char *get_insn_template PARAMS ((int, rtx));
 
+/* Add function NAME to the weak symbols list.  VALUE is a weak alias
+   associated with NAME.  */
+extern int add_weak PARAMS ((const char *, const char *));
+
 /* Functions in flow.c */
 extern void allocate_for_life_analysis	PARAMS ((void));
-extern int regno_uninitialized		PARAMS ((int));
+extern int regno_uninitialized		PARAMS ((unsigned int));
 extern int regno_clobbered_at_setjmp	PARAMS ((int));
-extern void dump_flow_info		PARAMS ((FILE *));
 extern void find_basic_blocks		PARAMS ((rtx, int, FILE *));
-extern void cleanup_cfg			PARAMS ((void));
-extern void free_basic_block_vars     PARAMS ((int));
-extern void set_block_num             PARAMS ((rtx, int));
+extern bool cleanup_cfg			PARAMS ((int));
 extern void check_function_return_warnings PARAMS ((void));
 #endif
 
@@ -154,13 +163,9 @@ extern void force_data_section		PARAMS ((void));
    the text section.  */
 extern void readonly_data_section	PARAMS ((void));
 
-/* Determine if we're in the text section. */
+/* Determine if we're in the text section.  */
 extern int in_text_section		PARAMS ((void));
 
-#ifdef EH_FRAME_SECTION_ASM_OP
-extern void eh_frame_section		PARAMS ((void));
-#endif
-
 #ifdef CTORS_SECTION_ASM_OP
 extern void ctors_section PARAMS ((void));
 #endif
@@ -185,10 +190,26 @@ extern void init_section PARAMS ((void));
 extern void fini_section PARAMS ((void));
 #endif
 
+#ifdef EXPORTS_SECTION_ASM_OP
+extern void exports_section PARAMS ((void));
+#endif
+
 #ifdef TDESC_SECTION_ASM_OP
 extern void tdesc_section PARAMS ((void));
 #endif
 
+#ifdef DRECTVE_SECTION_ASM_OP
+extern void drectve_section PARAMS ((void));
+#endif
+
+#ifdef SDATA_SECTION_ASM_OP
+extern void sdata_section PARAMS ((void));
+#endif
+
+#ifdef RDATA_SECTION_ASM_OP
+extern void rdata_section PARAMS ((void));
+#endif
+
 #ifdef TREE_CODE
 /* Tell assembler to change to section NAME for DECL.
    If DECL is NULL, just switch to section NAME.
@@ -199,11 +220,19 @@ extern void named_section		PARAMS ((tree, const char *, int));
 /* Tell assembler to switch to the section for function DECL.  */
 extern void function_section		PARAMS ((tree));
 
-/* Tell assembler to switch to the section for the exception table.  */
-extern void exception_section		PARAMS ((void));
+/* Tell assembler to switch to the section for string merging.  */
+extern void mergeable_string_section	PARAMS ((tree, unsigned HOST_WIDE_INT,
+						 unsigned int));
+
+/* Tell assembler to switch to the section for constant merging.  */
+extern void mergeable_constant_section	PARAMS ((enum machine_mode,
+						 unsigned HOST_WIDE_INT,
+						 unsigned int));
 
 /* Declare DECL to be a weak symbol.  */
 extern void declare_weak		PARAMS ((tree));
+/* Merge weak status.  */
+extern void merge_weak			PARAMS ((tree, tree));
 #endif /* TREE_CODE */
 
 /* Emit any pending weak declarations.  */
@@ -259,21 +288,6 @@ extern void assemble_variable		PARAMS ((tree, int, int, int));
 extern void assemble_external		PARAMS ((tree));
 #endif /* TREE_CODE */
 
-/* Record an element in the table of global destructors.
-   How this is done depends on what sort of assembler and linker
-   are in use.
-
-   NAME should be the name of a global function to be called
-   at exit time.  This name is output using assemble_name.  */
-extern void assemble_destructor		PARAMS ((const char *));
-
-/* Likewise for global constructors.  */
-extern void assemble_constructor	PARAMS ((const char *));
-
-/* Likewise for entries we want to record for garbage collection.
-   Garbage collection is still under development.  */
-extern void assemble_gc_entry		PARAMS ((const char *));
-
 /* Assemble code to leave SIZE bytes of zeros.  */
 extern void assemble_zeros		PARAMS ((int));
 
@@ -303,19 +317,40 @@ extern void assemble_eh_label		PARAMS ((const char *));
    Many macros in the tm file are defined to call this function.  */
 extern void assemble_name		PARAMS ((FILE *, const char *));
 
+/* Return the assembler directive for creating a given kind of integer
+   object.  SIZE is the number of bytes in the object and ALIGNED_P
+   indicates whether it is known to be aligned.  Return NULL if the
+   assembly dialect has no such directive.
+
+   The returned string should be printed at the start of a new line and
+   be followed immediately by the object's initial value.  */
+extern const char *integer_asm_op	PARAMS ((int, int));
+
 #ifdef RTX_CODE
-/* Assemble the integer constant X into an object of SIZE bytes.
-   X must be either a CONST_INT or CONST_DOUBLE.
+/* Use directive OP to assemble an integer object X.  Print OP at the
+   start of the line, followed immediately by the value of X.  */
+extern void assemble_integer_with_op	PARAMS ((const char *, rtx));
 
-   Return 1 if we were able to output the constant, otherwise 0.  If FORCE is
-   non-zero, abort if we can't output the constant.  */
-extern int assemble_integer		PARAMS ((rtx, int, int));
-extern int assemble_eh_integer		PARAMS ((rtx, int, int));
+/* The default implementation of the asm_out.integer target hook.  */
+extern bool default_assemble_integer	PARAMS ((rtx, unsigned int, int));
 
-#ifdef EMUSHORT
+/* Assemble the integer constant X into an object of SIZE bytes.  ALIGN is
+   the alignment of the integer in bits.  Return 1 if we were able to output
+   the constant, otherwise 0.  If FORCE is non-zero, abort if we can't output
+   the constant.  */
+extern bool assemble_integer		PARAMS ((rtx, unsigned, unsigned, int));
+
+/* An interface to assemble_integer for the common case in which a value is
+   fully aligned and must be printed.  VALUE is the value of the integer
+   object and SIZE is the number of bytes it contains.  */
+#define assemble_aligned_integer(SIZE, VALUE) \
+  assemble_integer (VALUE, SIZE, (SIZE) * BITS_PER_UNIT, 1)
+
+#ifdef REAL_VALUE_TYPE
 /* Assemble the floating-point constant D into an object of size MODE.  */
 extern void assemble_real		PARAMS ((REAL_VALUE_TYPE,
-					       enum machine_mode));
+					         enum machine_mode,
+						 unsigned));
 #endif
 #endif
 
@@ -358,13 +393,12 @@ extern tree initializer_constant_valid_p	PARAMS ((tree, tree));
    Assumes output_addressed_constants has been done on EXP already.
 
    Generate exactly SIZE bytes of assembler data, padding at the end
-   with zeros if necessary.  SIZE must always be specified.  */
-extern void output_constant		PARAMS ((tree, int));
-#endif
+   with zeros if necessary.  SIZE must always be specified.
 
-/* When outputting assembler code, indicates which alternative
-   of the constraints was actually satisfied.  */
-extern int which_alternative;
+   ALIGN is the alignment in bits that may be assumed for the data.  */
+extern void output_constant		PARAMS ((tree, HOST_WIDE_INT,
+						 unsigned int));
+#endif
 
 #ifdef RTX_CODE
 /* When outputting delayed branch sequences, this rtx holds the
@@ -376,13 +410,8 @@ extern int which_alternative;
 extern rtx final_sequence;
 #endif
 
-/* Nonzero means generate position-independent code.
-   This is not fully implemented yet.  */
-
-extern int flag_pic;
-
-/* The line number of the beginning of the current function.
-   sdbout.c needs this so that it can output relative linenumbers.  */
+/* The line number of the beginning of the current function.  Various
+   md code needs this so that it can output relative linenumbers.  */
 
 #ifdef SDB_DEBUGGING_INFO /* Avoid undef sym in certain broken linkers.  */
 extern int sdb_begin_function_line;
@@ -403,7 +432,7 @@ extern const char *weak_global_object_name;
 /* Nonzero if function being compiled doesn't contain any calls
    (ignoring the prologue and epilogue).  This is set prior to
    local register allocation and is valid for the remaining
-   compiler passes. */
+   compiler passes.  */
 
 extern int current_function_is_leaf;
 
@@ -414,7 +443,7 @@ extern int current_function_nothrow;
 
 /* Nonzero if function being compiled doesn't modify the stack pointer
    (ignoring the prologue and epilogue).  This is only valid after
-   life_analysis has run. */
+   life_analysis has run.  */
 
 extern int current_function_sp_is_unchanging;
 
@@ -457,6 +486,61 @@ extern const char *user_label_prefix;
 #define STRIP_NAME_ENCODING(VAR,SYMBOL_NAME) \
   (VAR) = ((SYMBOL_NAME) + ((SYMBOL_NAME)[0] == '*'))
 #endif
-/* Assign unique numbers to labels generated for profiling.  */
 
-extern int profile_label_no;
+/* Default target function prologue and epilogue assembler output.  */
+extern void default_function_pro_epilogue PARAMS ((FILE *, HOST_WIDE_INT));
+
+/* Tell assembler to switch to the section for the exception table.  */
+extern void default_exception_section	PARAMS ((void));
+
+/* Tell assembler to switch to the section for the EH frames.  */
+extern void default_eh_frame_section	PARAMS ((void));
+
+/* Default target hook that outputs nothing to a stream.  */
+extern void no_asm_to_stream PARAMS ((FILE *));
+
+/* Flags controling properties of a section.  */
+#define SECTION_ENTSIZE	 0x000ff	/* entity size in section */
+#define SECTION_CODE	 0x00100	/* contains code */
+#define SECTION_WRITE	 0x00200	/* data is writable */
+#define SECTION_DEBUG	 0x00400	/* contains debug data */
+#define SECTION_LINKONCE 0x00800	/* is linkonce */
+#define SECTION_SMALL	 0x01000	/* contains "small data" */
+#define SECTION_BSS	 0x02000	/* contains zeros only */
+#define SECTION_FORGET	 0x04000	/* forget that we've entered the section */
+#define SECTION_MERGE	 0x08000	/* contains mergeable data */
+#define SECTION_STRINGS  0x10000	/* contains zero terminated strings without
+					   embedded zeros */
+#define SECTION_OVERRIDE 0x20000	/* allow override of default flags */
+#define SECTION_MACH_DEP 0x40000	/* subsequent bits reserved for target */
+
+extern unsigned int get_named_section_flags PARAMS ((const char *));
+extern bool set_named_section_flags	PARAMS ((const char *, unsigned int));
+extern void named_section_flags		PARAMS ((const char *, unsigned int));
+extern bool named_section_first_declaration PARAMS((const char *));
+
+union tree_node;
+extern unsigned int default_section_type_flags PARAMS ((union tree_node *,
+							const char *, int));
+
+extern void default_no_named_section PARAMS ((const char *, unsigned int));
+extern void default_elf_asm_named_section PARAMS ((const char *, unsigned int));
+extern void default_coff_asm_named_section PARAMS ((const char *,
+						    unsigned int));
+extern void default_pe_asm_named_section PARAMS ((const char *, unsigned int));
+
+extern void default_stabs_asm_out_destructor PARAMS ((struct rtx_def *, int));
+extern void default_named_section_asm_out_destructor PARAMS ((struct rtx_def *,
+							      int));
+extern void default_dtor_section_asm_out_destructor PARAMS ((struct rtx_def *,
+							     int));
+extern void default_stabs_asm_out_constructor PARAMS ((struct rtx_def *, int));
+extern void default_named_section_asm_out_constructor PARAMS ((struct rtx_def *,
+							       int));
+extern void default_ctor_section_asm_out_constructor PARAMS ((struct rtx_def *,
+							      int));
+
+/* Emit data for vtable gc for GNU binutils.  */
+extern void assemble_vtable_entry PARAMS ((struct rtx_def *, HOST_WIDE_INT));
+extern void assemble_vtable_inherit PARAMS ((struct rtx_def *,
+					     struct rtx_def *));
